@@ -1,6 +1,9 @@
+import io
 import os
 import sys
 
+from lxml import etree
+
 from reqif.cli.cli_arg_parser import PassthroughCommandConfig
 
 from reqif.parser import ReqIFParser
@@ -28,6 +31,17 @@ class PassthroughCommand:
 
     @staticmethod
     def _passthrough(passthrough_config: PassthroughCommandConfig):
-        reqif_bundle = ReqIFParser.parse(passthrough_config.input_file)
+        with open(passthrough_config.input_file, "r", encoding="UTF-8") as file:
+            content = file.read()
+        try:
+            # Parse XML.
+            # https://github.com/eerohele/sublime-lxml/issues/5#issuecomment-209781719
+            xml_reqif_root = etree.parse(io.BytesIO(bytes(content, "UTF-8")))
+        except Exception as exception:  # pylint: disable=broad-except
+            # TODO: handle
+            print(f"error: problem parsing file: {exception}")
+            sys.exit(1)
+
+        reqif_bundle = ReqIFParser.parse_reqif(xml_reqif_root)
         reqif_xml_output = ReqIFUnparser.unparse(reqif_bundle)
         return reqif_xml_output
